<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css">
    <title>Real-time Location Update of Driver With Tracker</title>
    <style>
        #trackerHeading {
            font-size: 2.5em;
            color: #333;
            text-align: center;
        }
    </style>
</head>
<body>

    <script>
        // Check if another instance of the page is already running
        if (sessionStorage.getItem('locationPageRunning')) {
            alert('Another instance of the page is already running. Please close it first.');
            window.close(); // Close the current page
        } else {
            sessionStorage.setItem('locationPageRunning', 'true');

            // Add heading and tracker icon
            document.body.innerHTML += '<h2 id="trackerHeading">Tracker is ON <span style="font-size: 1.2em;">📍 <i class="fa fa-bus" aria-hidden="true"></i></span></h2>';
            document.body.innerHTML += '<h2 id="trackerHeading">Do not close this window; otherwise, the tracker will not be able to send location to the app.</h2>';

            function updateLocation() {
                if (navigator.geolocation) {
                    navigator.geolocation.getCurrentPosition(showPosition);
                } else {
                    alert("Geolocation is not supported by this browser.");
                }
            }

            function showPosition(position) {
                const latitude = position.coords.latitude;
                const longitude = position.coords.longitude;
                const timestamp = new Date(position.timestamp).toLocaleString('en-US', { timeZone: 'Asia/Karachi', hour12: true }); // Convert to Pakistan time
                const speed = position.coords.speed;

                // Reverse geocoding to get location name
                fetch(`https://nominatim.openstreetmap.org/reverse?format=json&lat=${latitude}&lon=${longitude}`)
                    .then(response => response.json())
                    .then(data => {
                        const locationName = data.display_name;

                        // Send the data to the server for saving to the database
                        saveLocationToDatabase(latitude, longitude, timestamp, speed, locationName);
                    })
                    .catch(error => {
                        console.error('Error fetching location name:', error);
                    });
            }

            function saveLocationToDatabase(latitude, longitude, timestamp, speed, locationName) {
                // Use an HTTP request (e.g., AJAX) to send the data to the server
                // Example using fetch API:
                fetch('<?php echo $_SERVER["PHP_SELF"]; ?>', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: `latitude=${latitude}&longitude=${longitude}&timestamp=${timestamp}&speed=${speed}&locationName=${locationName}`,
                })
                .then(response => response.json())
                .then(data => {
                    console.log('Location saved:', data);
                })
                .catch(error => {
                    console.error('Error saving location:', error);
                });
            }

            // Update location every 2 seconds (adjust the interval as needed)
            setInterval(updateLocation, 2000);

            // Call getLocation when the page loads
            updateLocation();

            // Listen for the beforeunload event to remove the sessionStorage item
            window.addEventListener('beforeunload', function() {
                sessionStorage.removeItem('locationPageRunning');
            });
        }
    </script>

<?php
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    parse_str(file_get_contents("php://input"), $post_vars); // Parse raw POST data
    // Handle the POST request and save the data to the database
    $latitude = $post_vars['latitude'];
    $longitude = $post_vars['longitude'];
    $timestamp = date('Y-m-d H:i:s', strtotime($post_vars['timestamp'])); // Correctly format the timestamp
    $speed = $post_vars['speed'];
    $locationName = $post_vars['locationName'];

    // Insert your database connection and save logic here
    // Example using MySQLi:
    $mysqli = new mysqli("localhost", "visigela_bus_tracking", "qqu)(.Gw~tsY", "visigela_bus_tracking");

    if ($mysqli->connect_error) {
        die("Connection failed: " . $mysqli->connect_error);
    }

    // Sanitize inputs to prevent SQL injection
    $latitude = $mysqli->real_escape_string($latitude);
    $longitude = $mysqli->real_escape_string($longitude);
    $timestamp = $mysqli->real_escape_string($timestamp);
    $speed = $mysqli->real_escape_string($speed);
    $locationName = $mysqli->real_escape_string($locationName);

    $sql = "INSERT INTO location_data (latitude, longitude, timestamp, speed, location_name) 
            VALUES ('$latitude', '$longitude', '$timestamp', '$speed', '$locationName')";

    if ($mysqli->query($sql) === TRUE) {
        echo json_encode(['success' => true, 'message' => 'Location saved successfully']);
    } else {
        echo json_encode(['success' => false, 'message' => 'Error saving location: ' . $mysqli->error]);
    }

    $mysqli->close();
    exit; // Prevent the rest of the HTML from being processed
}
?>

</body>
</html>
